/*
*  Header: "Bootloader" for ATTiny2313
*
* Description:
*
*  Bootloader somewhat compatible with "butterfly" "avr109" and "avr910" modes of avrdude
*
*  The attiny2313 has no direct bootloader support, so the application using it has to invoke the bootloader manually.
*  if the application already uses the serial port, listen for 0x1B 'S', and invoke "bootloader(1)"
*  otherwise, remove the "NO_SYNC" define below, and invoke "bootloader(0)"
*  avr910 doesn't use that escape code, here always bootloader(1) is needed.
*
*  you can create a library from this code and link your app against it, or directly flash a .hex from this code.
*
*  applications using this bootloader need to link against the lib anyways, so they can call the bootloader at all.
*
*  the write-flash code takes care that the bootloader itself can't be overwritten
*   (might cause flash verification errors if the bootloader versions mismatch)
*
*  link the resulting binary with LDFLAGS += -Wl,--section-start=.bootloader=0x500
*
*  This code is far from beeing optimized, it uses up almost half of the flash. Improved versions welcome.
*
*  This code uses the WDT to reset after flashing, the main application code is responsible for stopping the WDT again
*  if it doesn't use it. (WDT keeps running after reset)
*
* Author: Ernst Bachmann <e.bachmann@netandweb.de>, (C) 2006
*
* Copyright: See COPYING file that comes with this distribution
*
*/

#ifndef BOOTLOADER_H
#define BOOTLOADER_H
#include <stdint.h>

extern void bootloader(uint8_t);

#endif
